@@ -5,7 +5,11 @@ import traceback
 
 import explainaboard_client
 from explainaboard_client import ExplainaboardClient
-from explainaboard_client.utils import sanitize_for_json
+from explainaboard_client.client_utils import (
+    prompt_for_auto_upgrade_and_exit,
+    sanitize_for_json,
+)
+from explainaboard_client.exceptions import APIVersionMismatchException
 
 
 def main():
@@ -65,6 +69,13 @@ def main():
         nargs="+",
         help="Emails of users with which the system is shared",
     )
+    parser.add_argument(
+        "--system-tags",
+        type=str,
+        nargs="+",
+        help="User defined tags for the system,"
+        + "useful for searching and grouping systems",
+    )
     # ---- Display settings
     parser.add_argument(
         "--output-format",
@@ -116,6 +127,7 @@ def main():
             split=args.split,
             creator=args.creator,
             shared_users=args.shared_users,
+            system_tags=args.system_tags,
             page=args.page,
             page_size=args.page_size,
             sort_field=args.sort_field,
@@ -168,7 +180,8 @@ def main():
                     system["created_at"],
                 ] + metric_strs
                 print("\t".join(system_data))
-
+    except APIVersionMismatchException as e:
+        prompt_for_auto_upgrade_and_exit(e)
     except Exception:
         traceback.print_exc()
         print("failed to query systems")
